@@ -1,13 +1,12 @@
-from collections import deque
 import time
+from collections import deque
 from typing import Optional
 
 from bleak import BleakClient
 from bleak.backends.characteristic import BleakGATTCharacteristic
 from bleak.backends.scanner import AdvertisementData
-from numpy import byte
 
-from naneos.logger import LEVEL_DEBUG, LEVEL_INFO, get_naneos_logger
+from naneos.logger import LEVEL_INFO, get_naneos_logger
 from naneos.partector.blueprints._data_structure import Partector2DataStructure
 
 logger = get_naneos_logger(__name__, LEVEL_INFO)
@@ -150,12 +149,18 @@ class PartectorBleDevice:
         return decoded_data
 
     @classmethod
-    def get_naneos_adv(cls, naneos_adv: bytearray) -> tuple[Optional[bytes], Optional[int]]:
+    def get_naneos_adv(cls, adv: AdvertisementData) -> tuple[Optional[bytes], Optional[int]]:
         """
         Returns the custom advertisement data from Naneos devices.
 
         We are violating the BLE standard here by using the manufacturer data field for our own purposes.
         """
+
+        data_ble = adv.manufacturer_data
+        part1 = next(iter(data_ble.keys())).to_bytes(2, "big")
+        part2 = next(iter(data_ble.values()))
+        naneos_adv = part1 + part2
+
         # security check 2: The data must be 22 bytes long
         if len(naneos_adv) != 22:
             return (None, None)
